@@ -18,7 +18,7 @@ void Cast::PushNewMusicDataPacket(ting::Array<ting::byte> d){
 
 	//send the packet to all listeners
 	for(
-			T_ListenersIter i = this->listeners.begin();
+			T_ClientsIter i = this->listeners.begin();
 			i != this->listeners.end();
 			++i
 		)
@@ -32,16 +32,17 @@ void Cast::PushNewMusicDataPacket(ting::Array<ting::byte> d){
 
 void Cast::RemoveListener(ting::Ref<Client>& c){
 	for(
-			T_ListenersIter i = this->listeners.begin();
+			T_ClientsIter i = this->listeners.begin();
 			i != this->listeners.end();
 			++i
 		)
 	{
 		if(*i == c){
 			this->listeners.erase(i);
-			break;
+			return;
 		}
 	}
+	ASSERT_INFO(false, "Listener not found in cast")
 }
 
 void Cast::AddListenerAndSendDataToClient(ting::Ref<Client>& c){
