@@ -5,10 +5,6 @@
 // Description:
 //          Music playback thread class
 
-//#include "stdafx.hpp"
-//#include "MainThread.hpp"
-//#include "Preferences.hpp"
-
 #include <ting/Thread.hpp>
 #include <ting/debug.hpp>
 #include <ting/Ref.hpp>
@@ -205,12 +201,10 @@ void PlaybackThread::Run(){
 			//did not trigger, wait
 			u32 ms = curMusicAction->timestamp - timestampBias -
 					(ticks - localTimeOfStreamStart);
-			if(ms < 5){
-				Thread::Sleep(0);
-			}else if(ms > 500){
+			if(ms > 500){
 				Thread::Sleep(500);
 			}else{
-				Thread::Sleep(ms - 5);
+				Thread::Sleep(ms);
 			}
 		}
 	}//~while
