@@ -35,7 +35,8 @@ THE SOFTWARE. */
 #include <ting/Buffer.hpp>
 
 #include "backend/AudioBackend.hpp"
-#include "backend/ALSABackend.hpp"
+//#include "backend/ALSABackend.hpp"
+#include "backend/PulseAudioBackend.hpp"
 //#include "backend/ESoundBackend.hpp"
 
 using namespace aumiks;
@@ -108,7 +109,8 @@ static void CopyFromMixBufToPlayBuf(const Array<s32>& mixBuf, Array<ting::byte>&
 
 void Lib::SoundThread::Run(){
 	M_AUMIKS_TRACE(<< "Thread started" << std::endl)
-	ting::Ptr<aumiks::AudioBackend> backend(new ALSABackend(this->desiredBufferSizeInFrames));
+//	ting::Ptr<aumiks::AudioBackend> backend(new ALSABackend(this->desiredBufferSizeInFrames));
+	ting::Ptr<aumiks::AudioBackend> backend(new PulseAudioBackend(this->desiredBufferSizeInFrames));
 //	ting::Ptr<aumiks::AudioBackend> backend(new ESoundBackend(this->desiredBufferSizeInFrames));
 
 	ting::Array<s32> mixBuf(backend->BufferSizeInSamples());
