@@ -145,7 +145,7 @@ public:
 		{
 			this->SetFrequency(220);
 			this->pluckedString.SetLoopGain(1);
-			this->pluckedString.SetLoopFilterCoefs(0.95, 0.05);
+			this->pluckedString.SetLoopFilterCoefs(0.9, 0.1);
 		}
 
 		//override
@@ -189,9 +189,6 @@ public:
 	public:
 		Channel(){
 			this->bowed.SetFrequency(220);
-//			this->pluckedString.SetFrequency(220);
-//			this->pluckedString.SetLoopGain(1);
-//			this->pluckedString.SetLoopFilterCoefs(0.95, 0.05);
 		}
 
 		//override
@@ -203,8 +200,6 @@ public:
 		//override
 		void OnStart(){
 			this->bowed.StartBowing(1);
-//			this->pluckedString.Pluck(1.0);
-//			this->state = PLAYING;
 		}
 	private:
 		//override
@@ -446,4 +441,22 @@ public:
 
 
 
+class ThereminInstrument : public SampledInstrument{
+	ThereminInstrument() :
+			SampledInstrument(GenerateSample(), GetADSRParams())
+	{}
+
+
+	static Ref<Sample> GenerateSample();
+
+	static ADSRParams GetADSRParams();
+
+public:
+	static inline ting::Ref<ThereminInstrument> New(){
+		return ting::Ref<ThereminInstrument>(new ThereminInstrument());
+	}
+};
+
+
+
 }//~namespace
